@@ -2,7 +2,7 @@
 context("simulate successful request and reset session expiration")
 
 test_that("session age reset works as expected",{
-	session <- httr::handle("http://google.com")
+	session <- httr::handle("https://google.com")
 	attributes(session) <- c(attributes(session), list(birthdate=Sys.time()))
 	set_expiration(as.difftime("00:00:02"))
 	Sys.sleep(3)
@@ -17,7 +17,7 @@ test_that("session age reset ignores NULL session",{
 
 test_that("session age works on internal session",{
 	sbtools:::set_expiration(as.difftime("00:00:05"))
-	session <- httr::handle("http://google.com")
+	session <- httr::handle("https://google.com")
 	attributes(session) <- c(attributes(session), list(birthdate=Sys.time()))
 	sbtools:::session_set(session)
 	sbtools:::set_expiration(as.difftime("00:00:02"))
